Struct
QmiMessageLocStopOutput
since: 1.20
Description [src]
struct QmiMessageLocStopOutput {
/* No available fields */
}
The QmiMessageLocStopOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.20
Instance methods
qmi_message_loc_stop_output_ref
Atomically increments the reference count of self by one.
since: 1.20
qmi_message_loc_stop_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.20